function [Xsyn, L_ref, V_ref] = eci2synodic_eph(Xeci, svbody, mu1, mu2)

    % --> Xeci   = state vector in ECI RF
    % --> svbody = state vector at a particular epoch of the secondary body, eg. Moon if Earth-Moon system: svbody = svMoon
    % --> mu1    = mu primary body, eg. Earth
    % --> mu2    = mu secondary body, eg. Moon

    % --> Converts Cartesian Inertial to Synodic RF
    mu     = mu2/(mu1 + mu2);
    Xeci   = Xeci(:);
    svbody = svbody(:);
    L_ref  = norm(svbody(1:3));
    V_ref  = sqrt((mu1 + mu2)/L_ref);

    x_syn = svbody(1:3)/L_ref;
    h     = cross(svbody(1:3),svbody(4:6));
    z_syn = h/norm(h);
    y_syn = cross(z_syn, x_syn);
    A_t   = [x_syn, y_syn, z_syn];
    
    % --> Spacecraft
    r = A_t'*Xeci(1:3);
    v = A_t'*Xeci(4:6);
    n = norm(h)/L_ref^2;             % --> Instantaneous angular velocity
    
    % --> planet
    r_moon     = A_t'*svbody(1:3);
    v_moon     = A_t'*svbody(4:6);
    v_moon_rot = v_moon - cross([0 0 n],r_moon)';
    
    r_syn = (r/L_ref - [mu 0 0]');
    v_syn = (v - cross([0 0 n],r)' - v_moon_rot)/V_ref;
    Xsyn  = [r_syn; v_syn];
 
end

