function [OUTPUTref] = refineUsingASTRApath(path, INPUT)

% --> this function takes a path from ASTRA and refines it using ASTRA
% (i.e, looks for trajectories around the specified path with finer grids)

seq  = path(:,7)';
t0   = path(1,8);
tofs = path(2:end,11)';

t0days  = INPUT.t0days;
tofdays = INPUT.tofdays;
dt      = INPUT.dt;
revs    = INPUT.revs;
res     = INPUT.res;

t0min  = t0 - t0days;
t0max  = t0 + t0days;
tofmin = ( tofs - tofdays ).* ( ( tofs - tofdays ) >= 0 );
tofmax = ( tofs + tofdays );

INPUT.opt          = 1;
INPUT.vInfOpts     = [max([path(1,9)-0.5 3]) min([path(1,9)+0.5 5])];
INPUT.dsmOpts      = [max(path(:,10)) Inf];    % --> max defect DSM, and total DV (km/s)
INPUT.plot         = [0 0];      % --> plot(1) for pareto front, plot(2) for best traj.
INPUT.tstep        = dt;
INPUT.TOF_LIM      = [tofmin' tofmax']; % --> TOF limits per leg (days)
INPUT.chosenRevs   = revs;
INPUT.res          = res;
INPUT.depOpts      = [t0min t0max dt];

% --> solve using ASTRA
OUTPUTref = ASTRA_DP(seq, INPUT);

end