function [LEGSn, VASn, VINFn, nLP, nDEF] = wrap_FE_st2(LEGSnext, VASnext, legs, runOpts, indl, tstep, TOF_LIM, INPUT)

mu    = 132724487690;
dvLim = INPUT.dsmOpts(1);

pl1   = legs(indl,1);
pl2   = legs(indl,2);
optMR = runOpts(indl,:);

if pl2 <= 1193
    [~, minTOF, maxTOF, tst] = TOF_per_LEGS_ASTRA(pl1, pl2, optMR, tstep, TOF_LIM, indl);       % --> TOF for the given leg
else
    minTOF = 50;
    maxTOF = 2500;
    tst    = 10;
end

% tst

T0   = unique(LEGSnext(:,end), 'rows', 'stable');
TOFS = [minTOF:tst:maxTOF]';

% --> find next nodes (i.e. couples of planets with their visiting epochs)
[MAT, M1, M2] = generateMAT(pl1, pl2, T0, TOFS);
[EPH]         = wrap_generateEPH(M1, M2);

[muPL, radius] = planetConstants(pl1);
rpmin          = maxmin_flybyAltitude(pl1) + radius;

% --> number of defects
nDEF = numberOfDefects(LEGSnext, TOFS);
nLP  = size(MAT,1);

% --> solve the LP
STRUC = struct('LEGSn', cell(1, size(MAT,1)),...
                'VASn', cell(1, size(MAT,1)),...
                'VINFn', cell(1, size(MAT,1))); 

if INPUT.parallel == true
    parfor indm = 1:size(MAT,1)

        pl1        = MAT(indm,1);
        t1         = MAT(indm,2);
        pl2        = MAT(indm,3);
        t2         = MAT(indm,4);
        rr1        = EPH( EPH(:,1) == pl1 & EPH(:,2) == t1 , 3:5 );
        vv1        = EPH( EPH(:,1) == pl1 & EPH(:,2) == t1 , 6:8 );
        rr2        = EPH( EPH(:,1) == pl2 & EPH(:,2) == t2 , 3:5 );
        vv2        = EPH( EPH(:,1) == pl2 & EPH(:,2) == t2 , 6:8 );
        tof        = MAT(indm,4) - MAT(indm,2);
        
        % --> solve the LP
        [vvd, vva] = lambertMR(rr1, rr2, tof*86400, mu, optMR(1), optMR(2));

        % --> apply DP principles
        indxs   = find(LEGSnext(:,end-1) == pl1 & LEGSnext(:,end) == t1);
        legprev = LEGSnext(indxs,:);
        vasprev = VASnext(indxs,:);
        
        % --> compute the DEFECTS
        [legn, vvf, vinff] = computeDefects_DP(legprev, vasprev, pl2, t2, vv1, vv2, vvd, vva, dvLim, muPL, rpmin);

        % --> compute the pruning so not to stress memory
        [legn, vvf, vinff] = wrap_Pruning_DP(legn, vvf, vinff, INPUT);
        
        if ~isempty(legn)
                        
            % --> save ALLL the legs (since this is a FE)
            STRUC(indm).LEGSn = legn;
            STRUC(indm).VASn  = vvf;
            STRUC(indm).VINFn = vinff;
            
        end
        
    end
else
    for indm = 1:size(MAT,1)

        pl1        = MAT(indm,1);
        t1         = MAT(indm,2);
        pl2        = MAT(indm,3);
        t2         = MAT(indm,4);
        rr1        = EPH( EPH(:,1) == pl1 & EPH(:,2) == t1 , 3:5 );
        vv1        = EPH( EPH(:,1) == pl1 & EPH(:,2) == t1 , 6:8 );
        rr2        = EPH( EPH(:,1) == pl2 & EPH(:,2) == t2 , 3:5 );
        vv2        = EPH( EPH(:,1) == pl2 & EPH(:,2) == t2 , 6:8 );
        tof        = MAT(indm,4) - MAT(indm,2);
        
        % --> solve the LP
        [vvd, vva] = lambertMR(rr1, rr2, tof*86400, mu, optMR(1), optMR(2));

        % --> apply DP principles
        indxs   = find(LEGSnext(:,end-1) == pl1 & LEGSnext(:,end) == t1);
        legprev = LEGSnext(indxs,:);
        vasprev = VASnext(indxs,:);
        
        % --> compute the DEFECTS
        [legn, vvf, vinff] = computeDefects_DP(legprev, vasprev, pl2, t2, vv1, vv2, vvd, vva, dvLim, muPL, rpmin);
        strucNDEF(indm).legprev  = legprev;
        strucNDEF(indm).legnext  = [ pl1 t1 pl2 t2 ];

        % --> compute the pruning so not to stress memory
        [legn, vvf, vinff] = wrap_Pruning_DP(legn, vvf, vinff, INPUT);
        
        if ~isempty(legn)
                        
            % --> save ALLL the legs (since this is a FE)
            STRUC(indm).LEGSn = legn;
            STRUC(indm).VASn  = vvf;
            STRUC(indm).VINFn = vinff;
            
        end
        
    end
end

% --> extract info from STRUC
LEGSn = cell2mat({STRUC.LEGSn}');
VASn  = cell2mat({STRUC.VASn}');
VINFn = cell2mat({STRUC.VINFn}');

end
