function LEGS = firstLeg(legs, DEP_OPTS, ARR_OPTS, VINF_OPTS, Nrev)

% constants of motion
mu = 132724487690;

% extract info from initial options
t0       = DEP_OPTS(1); % mission start date
Dt0      = DEP_OPTS(2); % mission start date range
tsteptt0 = DEP_OPTS(3); % start interval

minTOF   = ARR_OPTS(1); % minimum transfer duration range 
maxTOF   = ARR_OPTS(2); % maximum transfer duration range 
tstepTT  = ARR_OPTS(3); % duration interval

% generate departure and arrival grids
tt0      = t0:tsteptt0:(t0+Dt0);
TT       = minTOF:tstepTT:maxTOF;

% set max/min vinfdep
vinfMin = VINF_OPTS(1);
vinfMax = VINF_OPTS(2);

nleg = 1;
s    = legs(nleg,:);

LEGS   = zeros(length(tt0)*length(TT), 20);
indleg = 1;    
for indi = 1:length(tt0)

    TDEP    = tt0(indi);

    [r1,v1] = EphSS_cartesian(s(1), TDEP);

    for indj = 1:length(TT)

        TOF     = TT(indj);

        [r2,v2] = EphSS_cartesian(s(2), TDEP + TOF);

        [v1Short, v2Short] = lambertMR(r1, r2, TOF*86400, mu, Nrev(1), Nrev(2));
        
        vInfD = norm(v1Short - v1);
        
        if vInfD <= vinfMax && vInfD >= vinfMin
            LEGS(indleg,:) = [r1 v1Short s(1) TDEP vInfD 0 r2 v2Short s(2) (TDEP + TOF) norm(v2 - v2Short) 0];
        end
        indleg = indleg + 1;   
    end
end

% --> eliminate rows all equal to zero
LEGS = LEGS(~all(LEGS == 0, 2),:);

end