function [STRUC] = generatePorkChop(s, DEP_OPTIONS, ARR_OPTIONS, Nrev, vinfDepOpt, generateDist)

% this function evaluates all the possible transfers between two planets
% with less than 1 spacecraft revolutions

if nargin == 3
    Nrev       = [0 0];
    vinfDepOpt = [0 Inf];
elseif nargin == 4
    vinfDepOpt = [0 Inf];
    generateDist = 0;
elseif nargin == 5
    generateDist = 0;
end

% --> constants of motion
mu = 132724487690;
AU = 149597870.7;

% --> extract info from initial options
t0       = DEP_OPTIONS(1); % --> mission start date
Dt0      = DEP_OPTIONS(2); % --> mission start date range
tsteptt0 = DEP_OPTIONS(3); % --> start interval

minTOF   = ARR_OPTIONS(1); % --> minimum transfer duration range 
maxTOF   = ARR_OPTIONS(2); % --> maximum transfer duration range 
tstepTT  = ARR_OPTIONS(3); % --> duration interval

% --> generate departure and arrival grids
tt0      = t0:tsteptt0:(t0+Dt0);
TT       = minTOF:tstepTT:maxTOF;

DV0      = zeros(length(tt0), length(TT));
VINFD    = zeros(length(tt0), length(TT));
VINFA    = zeros(length(tt0), length(TT));
MAXD     = zeros(length(tt0), length(TT));
MIND     = zeros(length(tt0), length(TT));
MAXDPL1  = zeros(length(tt0), length(TT));

meshTDEP = zeros(length(tt0), length(TT));
meshTOF  = zeros(length(tt0), length(TT));
meshTARR = zeros(length(tt0), length(TT));

for indi = 1:length(tt0)
    
    indi/length(tt0)*100

    TDEP    = tt0(indi);
    
    [r1,v1] = EphSS_cartesian(s(1), TDEP);
            
    for indj = 1:length(TT)
                
        % --> Build meshes for contour plot axis
        meshTDEP(indi,indj) = TDEP;
        meshTOF(indi,indj)  = TT(indj);
        meshTARR(indi,indj) = TDEP + TT(indj); % this is the arrival date at the planet
        
        [r2,v2] = EphSS_cartesian(s(2),TDEP + TT(indj));
                
        [v1Short, v2Short] = lambertMR(r1, r2, TT(indj)*86400, mu, Nrev(1), Nrev(2));
        dvShort            = norm(v1Short - v1) + norm(v2 - v2Short);

        if generateDist == 1
            rrd     = r1;
            vvd     = v1Short;
            tt      = linspace(0,TT(indj)*86400);
            [~,yy]  = propagateKepler(rrd, vvd, tt, mu);
            maxd    = max(vecnorm(yy(:,1:3)')')/AU;        % --> max Sun-SC distance
            mind    = min(vecnorm(yy(:,1:3)')')/AU;        % --> min Sun-SC distance
            maxdPl1 = max(vecnorm([yy(:,1:3) - r1]')')/AU; % --> max PL1-SC distance

%             plotPLTS(s, [TDEP TDEP + TT(indj)], 1);
%             hold on; grid on;
%             plot3( yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'b', 'LineWidth', 2 );

        end

        if norm(v1Short - v1) > vinfDepOpt(2)
            DV0(indi,indj)     = NaN;
            VINFD(indi,indj)   = NaN;
            VINFA(indi,indj)   = NaN;
            MAXD(indi,indj)    = NaN;
            MIND(indi,indj)    = NaN;
            MAXDPL1(indi,indj) = NaN;
        else
            DV0(indi,indj)   = dvShort;
            VINFD(indi,indj) = norm(v1Short - v1);
            VINFA(indi,indj) = norm(v2 - v2Short);
            if generateDist == 1
                MAXD(indi,indj)    = maxd;
                MIND(indi,indj)    = mind;
                MAXDPL1(indi,indj) = maxdPl1;
            end
        end
        
    end
    
end

STRUC.DV0      = DV0;
STRUC.VINFD    = VINFD;
STRUC.VINFA    = VINFA;
STRUC.MAXD     = MAXD;
STRUC.MIND     = MIND;
STRUC.MAXDPL1  = MAXDPL1;

STRUC.meshTDEP = meshTDEP;
STRUC.meshTARR = meshTARR;
STRUC.meshTOF  = meshTOF;

end
