function [VINFS] = vInfDepArr(path)

% DESCRIPTION : 
% find departing and arrival infinity velocity at planetary encounter
%
% INPUT :
% path : matrix containing the given path
% 
% OUTPUT :
% - VINFS : matrix containing departing and arrival infinity velocities,
%           for each leg of the transfer
%
% -------------------------------------------------------------------------

mu = 132724487690;

% first leg
row = 1;
rr1 = path(row, 1:3);
vv1 = path(row, 4:6);
pl1 = path(row, 7);
t1  = path(row, 8);

pl2 = path(row+1, 7);
t2  = path(row+1, 8);

tof = t2 - t1;

kep1       = car2kep([rr1, vv1], mu);
[~, vv2] = FGKepler_dt(kep1, tof*86400, mu);

[~, vvga2] = EphSS_car(pl2, t2);
[~, vvga1] = EphSS_car(pl1, t1);

vinfdep = norm(vv1 - vvga1);
vinfarr = norm(vv2 - vvga2);

VINFS      = zeros(size(path,1)-1,4);
VINFS(1,:) = [pl1 pl2 vinfdep vinfarr];

for indi = 3:size(path,1)
   
    rr2 = path(indi,1:3);
    vv2 = path(indi,4:6);
    pl2 = path(indi,7);
    t2  = path(indi,8);
    
    pl1 = path(indi-1,7);
    t1  = path(indi-1,8);
    
    dt       = t2 - t1;
    kep2     = car2kep([rr2, vv2], mu);
    [~, vv1] = FGKepler_dt(kep2, -dt*86400, mu);

    [~, vvga1] = EphSS_car(pl1, t1);
    [~, vvga2] = EphSS_car(pl2, t2);

    vinfdep = norm(vv1 - vvga1);
    vinfarr = norm(vv2 - vvga2);
    
    VINFS(indi-1,:) = [pl1 pl2 vinfdep vinfarr];

end

DEFECTS = path(2:end,10);
VINFS   = [VINFS DEFECTS];

end