function [RP, DELTA] = findFlyby_CC(vvrelIN, vvrelOU, plIN, tIN)

[~, radius, muPL] = astroConstantsj2000(plIN);
rpmin             = maxmin_flybyAltitude(plIN) + radius;

delta   = acos(dot(vvrelIN, vvrelOU)/(norm(vvrelIN)*norm(vvrelOU))); % turning angle
e_A     = 1 + (rpmin*norm(vvrelIN)^2)/muPL;                          % max. deflection hyperbola eccentricity
delta_A = 2*asin(1/e_A);                                             % max. deflection turning angle

delta   = wrapToPi(delta);
delta_A = wrapToPi(delta_A);

vvInfIN = vvrelIN;
vvInfOU = norm(vvrelIN).*vvrelOU./norm(vvrelOU);
if delta <= delta_A
    e      = 1/sin(delta/2);
    a      = -muPL/(norm(vvInfIN)^2);
    rp     = a*(1 - e);
    hp     = rp - radius;
else
    rp       = rpmin;
    hp       = rp - radius;  
    delta    = delta_A;
end

[~, vvga] = ephj2000(plIN, tIN);

ivers   = vvInfIN./norm(vvInfIN);
jvers   = cross(ivers, vvga)./norm(cross(ivers, vvga));
kvers   = cross(ivers, jvers);

MAT = [ivers' jvers' kvers'];
vec = 1/norm(vvInfOU).*(inv(MAT)*vvInfOU');
gam = atan(vec(3)/vec(2)); % from Izzo
gam = gam + pi/2;          % from Izzo to Ceriotti: the difference in phase is pi/2

RP    = [rp hp gam];
DELTA = [delta delta_A delta<=delta_A];

end