function [LEGSnext] = computeLegsCircCopl(plT, LEGSprev, tofs, tolDSM, Nrev, nleg)

% constants of motion
mu = 132724487690;

LEGSnext = zeros(size(LEGSprev,1)*length(tofs), (nleg + 1)*10);
indleg   = 1;

disp('Computing next leg ...');

if Nrev < 1
    
    % zero revolutions options
for indi = 1:size(LEGSprev,1) % loop over the number of first legs

    legPrev = LEGSprev(indi,:);
    
    plIN_2 = legPrev(:,end-3);
    tIN_2  = legPrev(:,end-2);
    vvIN_2 = legPrev(:,end-6:end-4);

    % dep. planet - is the arrival one of the previous leg
    [r1,v1]           = ephj2000(plIN_2, tIN_2);
    [~, radius, muPL] = astroConstantsj2000(plIN_2);
    [hmin]            = maxmin_flybyAltitude(plIN_2);
    rpmin             = hmin + radius;
    
    for indtof = 1:length(tofs)

        % tof for the next leg
        tof2 = tofs(indtof);

        % arrival planet of the next leg
        [r2,v2] = ephj2000(plT, tIN_2 + tof2);

        % zero revolution
        [~,~,~,~,v1Short, v2Short,~,~] = lambertMR(r1, r2, tof2*86400, mu, 0, 0);
                
        % short transfer is saved
        rrIN_3  = r2;
        vvIN_3  = v2Short;
        
        % compute the DV
        [dv] = findDV(vvIN_2 - v1, v1Short - v1, muPL, rpmin);
        
        if dv <= tolDSM
            % save the route
            leg = [rrIN_3 vvIN_3 plT tIN_2+tof2 norm(v2 - v2Short) dv];
            LEGSnext(indleg,:) = [legPrev leg];
            
        end
        indleg = indleg + 1;
    end
    
end
    
else
    
    % multiple revolutions option
    for indi = 1:size(LEGSprev,1) % loop over the number of first legs

        legPrev = LEGSprev(indi,:);

        plIN_2 = legPrev(:,end-3);
        tIN_2  = legPrev(:,end-2);
        vvIN_2 = legPrev(:,end-6:end-4);

        % dep. planet (Venus in this case) - is the arrival one of the previous leg
        [r1,v1]           = ephj2000(plIN_2, tIN_2);
        [~, radius, muPL] = astroConstantsj2000(plIN_2);
        [hmin]            = maxmin_flybyAltitude(plIN_2);
        rpmin             = hmin + radius;
        
        for indtof = 1:length(tofs)

            % tof for the next leg
            tof2 = tofs(indtof);

            % arrival planet of the next leg (Mars in this case)
            [r2,v2] = ephj2000(plT, tIN_2 + tof2);
            
            % two revolutions
            [~,~,~,~,v1Short, v2Short,~,~] = lambertMR(r1, r2, tof2*86400, mu, 0, Nrev, 0, 0);
            [dvShort] = findDV(vvIN_2 - v1, v1Short - v1, muPL, rpmin);

            [~,~,~,~,v1Long, v2Long,~,~] = lambertMR(r1, r2, tof2*86400, mu, 0, Nrev, 1, 0);
            [dvLong] = findDV(vvIN_2 - v1, v1Long - v1, muPL, rpmin);

            [~, b] = min([dvShort dvLong]);
            
            if b == 1
                % short transfer is saved
                rrIN_3  = r2;
                vvIN_3  = v2Short;
                dv      = dvShort;
            elseif b == 2
                % long transfer is saved
                rrIN_3  = r2;
                vvIN_3  = v2Long;
                dv      = dvLong;
            end

            if dv < tolDSM
                % save the route
                leg = [rrIN_3 vvIN_3 plT tIN_2+tof2 norm(v2 - vvIN_3) dv];
                LEGSnext(indleg,:) = [legPrev leg];
            end
            indleg = indleg + 1;
        end

    end
    
end

% eliminate rows all equal to zero
LEGSnext = LEGSnext(~all(LEGSnext == 0, 2),:);

disp('Done!!!');

end