function plotTime_AMB_seq(seq, t0, tofs, flyby, param, optsMR)

% --> flyby is assumed on the last planet
mu = 132724487690;
AU = 149597870.7;

epochs    = zeros(length(seq), 1);
epochs(1) = t0;
for inds = 1:length(tofs)
    epochs(inds+1) = epochs(inds) + tofs(inds);
end

figure; 
hold on; grid on; axis equal;
xlabel('x - AU'); ylabel('y - AU'); 

% --> AMB limits
xxMIN = param.rcMIN.*cos([linspace(0, 2*pi)]);
yyMIN = param.rcMIN.*sin([linspace(0, 2*pi)]);
xxMAX = param.rcMAX.*cos([linspace(0, 2*pi)]);
yyMAX = param.rcMAX.*sin([linspace(0, 2*pi)]);

% --> plot the AMB limits
plot(xxMIN./AU , yyMIN./AU ,'k--', 'Linewidth', 2, 'handlevisibility', 'off');
plot(xxMAX./AU , yyMAX./AU ,'k--', 'Linewidth', 2, 'DisplayName', 'AMB limits');

% --> plot Sun texture
plot_sun(0.3, [0 0 0]);

% --> plot planets
for inds = 1:length(seq)
    pl       = seq(inds);
    [rr, vv] = EphSS_car(seq(inds), epochs(inds));
    kep      = car2kep([rr vv], mu);
    plotEllipse_SC(kep);
end

% --> plot Earth texture
[rr1] = EphSS_car(seq(1), t0);


dtAMB1 = zeros(length(seq)-1, 1);
for inds = 1:length(seq)-1
   
    pl1 = seq(inds);
    pl2 = seq(inds+1);
    t1  = epochs(inds);
    t2  = epochs(inds+1);
    
    [rr1, vv1] = EphSS_car(pl1, t1);
    if pl1 == 3
        plot_earth(0.2, [rr1(1) rr1(2) rr1(3)]./AU);
    elseif pl1 == 4
        plot_mars(0.2, [rr1(1) rr1(2) rr1(3)]./AU);
    elseif pl1 == 5
        plot_jupiter(0.2, [rr1(1) rr1(2) rr1(3)]./AU);
    elseif pl1 == 2
        plot_venus(0.2, [rr1(1) rr1(2) rr1(3)]./AU);
    end

    [rr2, vv2] = EphSS_car(pl2, t2);
    if pl2 == 3
        plot_earth(0.2, [rr2(1) rr2(2) rr2(3)]./AU);
    elseif pl2 == 4
        plot_mars(0.2, [rr2(1) rr2(2) rr2(3)]./AU);
    elseif pl2 == 5
        plot_jupiter(0.2, [rr2(1) rr2(2) rr2(3)]./AU);
    elseif pl2 == 2
        plot_venus(0.2, [rr2(1) rr2(2) rr2(3)]./AU);
    end
    
    % --> solve the LP
    [vvd, vva] = lambertMR(rr1, rr2, (t2 - t1)*86400, mu, optsMR(inds,1), optsMR(inds,2));
    
    rr1
    vvd
    
    % --> time in the AMB for the first phase
    [dtAMB1(inds,1), ~, yyAMB1, yypruned1] = time_AMB(rr1, vvd, param.rcMIN, param.rcMAX, (t2 - t1)*86400);
    
    plot3(yypruned1(:,1)./AU, yypruned1(:,2)./AU, yypruned1(:,3)./AU, 'b', 'linewidth', 2, 'handlevisibility', 'off');
    plot3(yyAMB1(:,1)./AU, yyAMB1(:,2)./AU, yyAMB1(:,3)./AU, 'r.', 'markersize', 15, 'handlevisibility', 'off');
    
end

dtAMB1 = sum(dtAMB1);             % --> time in the AMB for the previous legs
TOF    = epochs(end) - epochs(1);

if isempty(flyby)
    
else
    % --> perform the flyby
    rpin         = flyby(1);
    kin          = flyby(2);
    muPLIN       = planetConstants(pl2);
    [rrOU, vvOU] = swingby_vA(rr2, vva, pl2, t2, kin, rpin, muPLIN);

    [dtAMB2, T2, yyAMB2, yypruned2] = time_AMB(rrOU, vvOU, param.rcMIN, param.rcMAX);

    % --> time in the AMB
    dtAMB = dtAMB1 + (param.maxDur - TOF)/T2 * dtAMB2;

    plot3(yypruned2(:,1)./AU, yypruned2(:,2)./AU, yypruned2(:,3)./AU, 'b', 'linewidth', 2, 'handlevisibility', 'off');
    plot3(yyAMB2(:,1)./AU, yyAMB2(:,2)./AU, yyAMB2(:,3)./AU, 'r.', 'markersize', 15,...
        'DisplayName', 'Trajectory in the AMB');

    legend('Location', 'Best');
end

end

