function [STRUC] = wrap_Process_STRUC_AMB(LEGS, REVS, dtAMB, param)

% --> extract the parameters
rcMIN = param.rcMIN;
rcMAX = param.rcMAX;
TOFr  = param.TOFr;
mu    = 132724487690;

seq   = LEGS(1,7:10:end-3);

% --> perform the fly-by with Mars and compute orbit that maximises the DTamb
STRUC = struct('indl', [], 'tDEP', [], 'tIN', [], 'vInfDep', [], 'rpin', [], ...
            'kin', [], 'tofAMB', [], 'incOUdeg', [], 'pl1', [], 'pl2', [], 'revs', [],...
            'epochs', []);
parfor indl = 1:size(LEGS,1)
    tic
    STRUC(indl) = wrap_AMB(LEGS, REVS, rcMIN, rcMAX, TOFr, dtAMB, indl);
    toc
end
emptyIndex          = find(arrayfun(@(STRUC) isempty(STRUC.indl),STRUC))';
STRUC(emptyIndex)   = [];

for inds = 1:length(STRUC)
    opts = STRUC(inds).revs;
    OPTS = NaN.*ones( length(opts) , 2);
    for indl = 1:length(opts)
        revs = opts(indl);
        if revs == 0
            revs = [0 0];
        else
            m    = floor(log10(revs));
            revs = mod(floor(revs ./ 10 .^ (m:-1:0)), 10);
        end
        OPTS(indl,:) = revs;
    end
    STRUC(inds).revs = OPTS;
end

for inds = 1:length(STRUC)
    
    indl = STRUC(inds).indl;
   
    legrow = LEGS(indl,:);
    path   = constructPath(legrow);
    rrd    = zeros(size(path,1)-1,3);
    vvd    = zeros(size(path,1)-1,3);
    for indp = 2:size(path,1)
        rrin = path(indp,1:3);
        vvin = path(indp,4:6);
        tof  = path(indp,11)*86400;
        [rrd(indp-1,:), vvd(indp-1,:)] = FGKepler_dt(car2kep([rrin vvin], mu), -tof, mu);
    end
    STRUC(inds).stated = [rrd vvd];
end

STRUC(1).seq        = seq;
STRUC(1).meanDT_AMB = mean([STRUC.tofAMB]');
STRUC(1).maxDT_AMB  = max([STRUC.tofAMB]');
STRUC(1).minDT_AMB  = min([STRUC.tofAMB]');

end
