/*
 * Academic License - for use in teaching, academic research, and meeting
 * course requirements at degree granting institutions only.  Not for
 * government, commercial, or other organizational use.
 * File: paretoFront.c
 *
 * MATLAB Coder version            : 5.2
 * C/C++ source code generated on  : 12-Jan-2022 11:22:09
 */

/* Include Files */
#include "paretoFront.h"
#include "bsxfun.h"
#include "combineVectorElements.h"
#include "nullAssignment.h"
#include "paretoFront_emxutil.h"
#include "paretoFront_types.h"
#include "rt_nonfinite.h"
#include "sortrows.h"

/* Function Definitions */
/*
 * Filters a set of points P according to Pareto dominance, i.e., points
 *  that are dominated (both weakly and strongly) are filtered.
 *
 *  Inputs:
 *  - P    : N-by-D matrix, where N is the number of points and D is the
 *           number of elements (objectives) of each point.
 *
 *  Outputs:
 *  - P    : Pareto-filtered P
 *  - idxs : indices of the non-dominated solutions
 *
 *  Example:
 *  p = [1 1 1; 2 0 1; 2 -1 1; 1, 1, 0];
 *  [f, idxs] = paretoFront(p)
 *      f = [1 1 1; 2 0 1]
 *      idxs = [1; 2]
 *
 * Arguments    : const double p[2000000]
 *                emxArray_real_T *PP
 *                emxArray_real_T *idxs
 * Return Type  : void
 */
void paretoFront(const double p[2000000], emxArray_real_T *PP,
                 emxArray_real_T *idxs)
{
  emxArray_boolean_T *b_p;
  emxArray_boolean_T *indices;
  emxArray_boolean_T *r1;
  emxArray_int32_T *r;
  emxArray_int32_T *y;
  emxArray_real_T *b_PP;
  double c_PP[2];
  double b_i;
  int i;
  int k;
  int k0;
  int nxin;
  int nxout;
  int old_size;
  signed char input_sizes_idx_1;
  signed char sizes_idx_1;
  boolean_T empty_non_axis_sizes;
  emxInit_real_T(&b_PP, 2);
  /*  disp('Computing Pareto front...'); */
  i = b_PP->size[0] * b_PP->size[1];
  b_PP->size[0] = 1000000;
  b_PP->size[1] = 2;
  emxEnsureCapacity_real_T(b_PP, i);
  for (i = 0; i < 2000000; i++) {
    b_PP->data[i] = p[i];
  }
  emxInit_boolean_T(&b_p, 1);
  i = b_p->size[0];
  b_p->size[0] = 1000000;
  emxEnsureCapacity_boolean_T(b_p, i);
  for (i = 0; i < 1000000; i++) {
    b_p->data[i] = (p[i] == 0.0);
  }
  nullAssignment(b_PP, b_p);
  nxout = b_PP->size[0] * 2;
  i = b_PP->size[0] * b_PP->size[1];
  b_PP->size[1] = 2;
  emxEnsureCapacity_real_T(b_PP, i);
  emxFree_boolean_T(&b_p);
  for (i = 0; i < nxout; i++) {
    b_PP->data[i] = -b_PP->data[i];
  }
  emxInit_int32_T(&y, 2);
  b_i = b_PP->size[0];
  if (b_PP->size[0] < 1) {
    y->size[0] = 1;
    y->size[1] = 0;
  } else {
    nxout = b_PP->size[0];
    i = y->size[0] * y->size[1];
    y->size[0] = 1;
    y->size[1] = b_PP->size[0];
    emxEnsureCapacity_int32_T(y, i);
    for (i = 0; i < nxout; i++) {
      y->data[i] = i + 1;
    }
  }
  i = idxs->size[0];
  idxs->size[0] = y->size[1];
  emxEnsureCapacity_real_T(idxs, i);
  nxout = y->size[1];
  for (i = 0; i < nxout; i++) {
    idxs->data[i] = y->data[i];
  }
  emxFree_int32_T(&y);
  emxInit_boolean_T(&indices, 1);
  emxInit_int32_T(&r, 1);
  emxInit_boolean_T(&r1, 2);
  while (b_i >= 1.0) {
    old_size = b_PP->size[0];
    c_PP[0] = b_PP->data[(int)b_i - 1];
    c_PP[1] = b_PP->data[((int)b_i + b_PP->size[0]) - 1];
    bsxfun(c_PP, b_PP, r1);
    combineVectorElements(r1, r);
    i = indices->size[0];
    indices->size[0] = r->size[0];
    emxEnsureCapacity_boolean_T(indices, i);
    nxout = r->size[0];
    for (i = 0; i < nxout; i++) {
      indices->data[i] = (r->data[i] == 2);
    }
    indices->data[(int)b_i - 1] = false;
    nullAssignment(b_PP, indices);
    nxin = idxs->size[0];
    k0 = 0;
    i = indices->size[0];
    for (k = 0; k < i; k++) {
      k0 += indices->data[k];
    }
    nxout = idxs->size[0] - k0;
    k0 = -1;
    for (k = 0; k < nxin; k++) {
      if ((k + 1 > indices->size[0]) || (!indices->data[k])) {
        k0++;
        idxs->data[k0] = idxs->data[k];
      }
    }
    i = idxs->size[0];
    if (1 > nxout) {
      idxs->size[0] = 0;
    } else {
      idxs->size[0] = nxout;
    }
    emxEnsureCapacity_real_T(idxs, i);
    if ((int)b_i > indices->size[0]) {
      i = 0;
      nxin = 0;
    } else {
      i = (int)b_i - 1;
      nxin = indices->size[0];
    }
    nxout = nxin - i;
    if (nxout == 0) {
      k0 = 0;
    } else {
      k0 = indices->data[i];
      for (k = 2; k <= nxout; k++) {
        k0 += indices->data[(i + k) - 1];
      }
    }
    b_i = ((b_i - 1.0) - (double)(old_size - b_PP->size[0])) + (double)k0;
  }
  emxFree_boolean_T(&r1);
  emxFree_int32_T(&r);
  emxFree_boolean_T(&indices);
  nxout = b_PP->size[0] * 2;
  i = b_PP->size[0] * b_PP->size[1];
  b_PP->size[1] = 2;
  emxEnsureCapacity_real_T(b_PP, i);
  for (i = 0; i < nxout; i++) {
    b_PP->data[i] = -b_PP->data[i];
  }
  if (b_PP->size[0] != 0) {
    k0 = b_PP->size[0];
  } else if (idxs->size[0] != 0) {
    k0 = idxs->size[0];
  } else {
    k0 = 0;
  }
  empty_non_axis_sizes = (k0 == 0);
  if (empty_non_axis_sizes || (b_PP->size[0] != 0)) {
    input_sizes_idx_1 = 2;
  } else {
    input_sizes_idx_1 = 0;
  }
  if (empty_non_axis_sizes || (idxs->size[0] != 0)) {
    sizes_idx_1 = 1;
  } else {
    sizes_idx_1 = 0;
  }
  i = PP->size[0] * PP->size[1];
  PP->size[0] = k0;
  PP->size[1] = input_sizes_idx_1 + sizes_idx_1;
  emxEnsureCapacity_real_T(PP, i);
  nxout = input_sizes_idx_1;
  for (i = 0; i < nxout; i++) {
    for (nxin = 0; nxin < k0; nxin++) {
      PP->data[nxin + PP->size[0] * i] = b_PP->data[nxin + b_PP->size[0] * i];
    }
  }
  emxFree_real_T(&b_PP);
  nxout = sizes_idx_1;
  for (i = 0; i < nxout; i++) {
    for (nxin = 0; nxin < k0; nxin++) {
      PP->data[nxin + PP->size[0] * input_sizes_idx_1] = idxs->data[nxin];
    }
  }
  sortrows(PP);
  /*  disp('Done!!!'); */
}

/*
 * File trailer for paretoFront.c
 *
 * [EOF]
 */
