function [figECI, STRUC, figSYN, figRSC, figVSC] = plotPath(path, holdon, color, firstL)

if nargin == 1
    holdon = 0;   % --> open new figure
    color  = 'b'; % --> blue trajectory
    firstL = 1;   % --> highlight departing condition
elseif nargin == 2
    color = 'b';
    firstL = 1;
elseif nargin == 3
    firstL = 1;
end

mu = 132724487690;
AU = 149597870.7;

PLTS = path(:,7);
TFBS = path(:,8);
DTS  = [0; diff(TFBS)];

%%%%% plot planets orbits %%%%%
t0     = path(1,8);
tend   = path(end,8);
figECI = plotPLTS_tt(PLTS, t0, tend, holdon);
%%%%% plot planets orbits %%%%%

%%%%% plot trajectory %%%%%
YY = []; TT = [];
for NLEG = 2:size(path,1)
    
    RR  = path(NLEG, 1:3);
    VV  = path(NLEG, 4:6);
    
    [rr1, vv1] = FGKepler_dt(car2kep([RR VV], mu), -DTS(NLEG)*86400, mu); % backward propagation
    tt         = [0:1*86400:DTS(NLEG)*86400]';
    [~,yy]     = propagateKepler(rr1, vv1, tt, mu); % forward propagation

    if firstL == 1
        if NLEG == 2
            hold on;
            plot3(yy(1,1)./AU, yy(1,2)./AU, yy(1,3)./AU,...
                's', 'MarkerSize', 10, 'MarkerEdgeColor', 'Black', 'MarkerFaceColor', 'Cyan', 'DisplayName', 'Departure');
        end
    end
    
    if NLEG  == 2
        hold on;
        plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'Color', color, 'linewidth', 2, 'HandleVisibility', 'Off');
        if holdon == 0
            plot3(yy(end,1)./AU, yy(end,2)./AU, yy(end,3)./AU, ...
                'o', 'MarkerSize', 8, 'MarkerEdgeColor', 'Black', 'MarkerFaceColor', 'Red', 'DisplayName', 'Fly-by');
        else
            plot3(yy(end,1)./AU, yy(end,2)./AU, yy(end,3)./AU, ...
                'o', 'MarkerSize', 8, 'MarkerEdgeColor', 'Black', 'MarkerFaceColor', 'Red', 'HandleVisibility', 'Off');
        end
    else
        hold on;
        plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU,...
            'Color', color, 'linewidth', 2, 'HandleVisibility', 'Off');
        plot3(yy(end,1)./AU, yy(end,2)./AU, yy(end,3)./AU,...
            'o', 'MarkerSize', 8, 'MarkerEdgeColor', 'Black', 'MarkerFaceColor', 'Red', 'HandleVisibility', 'Off');
    end
    
    YY = [YY; yy];
    if NLEG == 2
        TT = [TT; ((tt))];
    else
        TT = [TT; TT(end)+(tt)];
    end
    
end
TT = path(1,8) + TT./86400;
%%%%% plot trajectory %%%%%

%%%%% distance and velocity w.r.t. time %%%%%
R = vecnorm(YY(:,1:3)')';
V = vecnorm(YY(:,4:6)')';
%%%%% distance and velocity w.r.t. time %%%%%

%%%%% planets positions in the time considered %%%%%
TPLTS = TT;
PLTS  = unique(PLTS);
for indj = 1:length(PLTS)
    pl               = PLTS(indj);
    PLANETS(indj).pl = pl;
    for indi = 1:length(TPLTS)
        [rr, vv]                           = EphSS_cartesian(pl, TPLTS(indi));
        PLANETS(indj).statesPL_ECI(indi,:) = [rr, vv];
        PLANETS(indj).Tpl(indi,:)          = TPLTS(indi);
    end
    [statesPL_SYN]             = wrapECI2Synodic_SE(PLANETS(indj).statesPL_ECI, PLANETS(indj).Tpl);
    PLANETS(indj).statesPL_SYN = statesPL_SYN;
end
%%%%% planets positions in the time considered %%%%%

%%%%% save the results %%%%%
STRUC.StatesSC = YY;
STRUC.EpochsSC = TT;
STRUC.TOFsSC   = [0; TT(2:end) - TT(1)];
STRUC.DistSC   = R;
STRUC.VelSC    = V;

STRUC.SatesScFB  = path(:,1:6);
STRUC.EpochsScFB = path(:,8);

STRUC.Planets    = PLANETS;

% --> from ECLIPTIC J2000 to SUN-EARTH SYNODIC reference frame
[statesSC_SYN] = wrapECI2Synodic_SE(STRUC.StatesSC, STRUC.EpochsSC);
[statesPL_SYN] = wrapECI2Synodic_SE(STRUC.SatesScFB, STRUC.EpochsScFB);

STRUC.StatesSC_syn   = statesSC_SYN;
STRUC.StatesScFB_syn = statesPL_SYN;

%%%%% save the results %%%%%

if nargout >= 3

    figSYN = figure( 'Color', [1 1 1] );
    hold on; grid on; axis equal;
    xlabel('x - AU'); ylabel('y - AU'); zlabel('z - AU');
    
    plot3(STRUC.StatesSC_syn(:,1), STRUC.StatesSC_syn(:,2), STRUC.StatesSC_syn(:,3), 'b', 'LineWidth', 2, 'HandleVisibility', 'off');
    
    plot3( STRUC.StatesScFB_syn(2:end,1), STRUC.StatesScFB_syn(2:end,2), STRUC.StatesScFB_syn(2:end,3), ...
        'o', 'MarkerSize', 8, 'MarkerEdgeColor', 'Black', 'MarkerFaceColor', 'Red', 'DisplayName', 'Fly-by');
    plot3( STRUC.StatesScFB_syn(1,1), STRUC.StatesScFB_syn(1,2), STRUC.StatesScFB_syn(1,3), ...
        's', 'MarkerSize', 10, 'MarkerEdgeColor', 'Black', 'MarkerFaceColor', 'Cyan', 'DisplayName', 'Departure');
    
    for indpl = 1:length(STRUC.Planets)
        plot3(STRUC.Planets(indpl).statesPL_SYN(:,1), STRUC.Planets(indpl).statesPL_SYN(:,2), STRUC.Planets(indpl).statesPL_SYN(:,3), ...
            'k', 'linewidth', 0.5, 'HandleVisibility', 'Off');
    end

    if nargout >= 4


        figRSC = figure( 'Color', [1 1 1] );
        hold on; grid on;
        xlabel('Days from launch'); ylabel('Sun-spacecraft distance - AU');

        plot(STRUC.TOFsSC, STRUC.DistSC./AU, 'b', 'linewidth', 2, 'HandleVisibility', 'off');
        
        distfb = vecnorm( STRUC.SatesScFB(:,1:3)' )';
        toffb  = [ 0; STRUC.EpochsScFB(2:end) - STRUC.EpochsScFB(1) ];

        plot(toffb(1), distfb(1)./AU, ...
            's', 'MarkerSize', 10, 'MarkerEdgeColor', 'Black', 'MarkerFaceColor', 'Cyan', 'DisplayName', 'Departure');

        plot(toffb(2:end), distfb(2:end)./AU, ...
            'o', 'MarkerSize', 8, 'MarkerEdgeColor', 'Black', 'MarkerFaceColor', 'Red', 'DisplayName', 'Fly-by');

        if nargout == 5
            figVSC = figure( 'Color', [1 1 1] );
            hold on; grid on;
            xlabel('Days from launch'); ylabel('Spacecraft velocity - km/s');

            plot(STRUC.TOFsSC, STRUC.VelSC, 'b.', 'MarkerSize', 5, 'HandleVisibility', 'off');

            velfb = vecnorm( STRUC.SatesScFB(:,4:6)' )';
            toffb = [ 0; STRUC.EpochsScFB(2:end) - STRUC.EpochsScFB(1) ];

            plot(toffb(1), velfb(1), ...
                's', 'MarkerSize', 10, 'MarkerEdgeColor', 'Black', 'MarkerFaceColor', 'Cyan', 'DisplayName', 'Departure');

            plot(toffb(2:end), velfb(2:end), ...
                'o', 'MarkerSize', 8, 'MarkerEdgeColor', 'Black', 'MarkerFaceColor', 'Red', 'DisplayName', 'Fly-by');

            

        end

    end

end

end
