function [LEGSnext, MMAT] = resonancesBack(LEGS, legsf, indleg, res, tolDSM)

mu     = 132724487690;
pl2    = legsf(indleg,1);
pl1    = legsf(indleg,2);

[muPL, radius] = planetConstants(pl2);
rpmin          = maxmin_flybyAltitude(pl2) + radius;

LEGSnext   = zeros(5e6, size(LEGS,2)+10);
MMAT       = zeros(5e6, 16);
indlegnext = 1;
for indl = 1:size(LEGS,1)
    
    indl/size(LEGS,1)*100
    
    pl            = LEGS(indl,7);                                  % --> planet
    [~, ~, smapl] = planetConstants(pl);                           % --> planet semi-major axis
    dt            = (res(1)/res(2)*(2*pi*sqrt(smapl^3/mu)))/86400; % --> transfer time (of the resonant orbit)
    tpl           = LEGS(indl,8) - dt;                             % --> epoch of the first flyby

    % --> resonant orbits w.r.t. infinity velocity
    MAT = wrapResonance_Back(pl, res, tpl);
    
    % --> previous leg
    legprev = LEGS(indl,:);
    
    t2  = legprev(8);
    tt1 = t2 - dt;
    
    [~, vv1] = EphSS_car(pl1, tt1);
    [rr2, vv2] = EphSS_car(pl2, t2);
    
    for indm = 1:size(MAT,1)
       
        vi           = MAT(indm,4:6);        % --> initial velocity on the leg
        vf           = MAT(indm,11:13);      % --> final velocity on the leg
        vvinfa       = vf - vv2;             % --> arrival infinity velocity
        vinfa        = norm(vvinfa);
        legprev(9)   = vinfa;
        rr1          = MAT(indm,1:3);        % --> initial position vector
        legprev(4:6) = vi;                   % --> initial velocity vector
        vvinfd       = legprev(14:16) - vv2; % --> departing infinity velocity
        
        dv           = findDV(vvinfa, vvinfd, muPL, rpmin);
        legprev(20)  = dv;
        
        if dv <= tolDSM(1)
            if indleg == size(legsf,1)
                vec         = vi;
                vinf_d      = norm(vi - vv1);
                dv_d        = 0;
                legprev(10) = 0;
            else
                vec    = [NaN NaN NaN];
                vinf_d = NaN;
                dv_d   = NaN;
            end
            LEGSnext(indlegnext,:) = [rr1 vec pl1 tt1 vinf_d dv_d...
                                      legprev];
            MMAT(indlegnext,:)     = [rr1 vi pl1 tt1 rr2 vf pl2 t2];
            indlegnext             = indlegnext + 1;
        end
    end
end
LEGSnext = LEGSnext(~all(LEGSnext == 0, 2),:);
MMAT     = MMAT(~all(MMAT == 0, 2),:);

end