function [STRUC] = wrap_FB(LEGS, REVS, vdep, indl)

% --> gravitational parameter of the Sun
mu = 132724487690;

% --> extract info
plIN    = LEGS(indl,end-3);
rrIN    = LEGS(indl,end-9:end-7);
vvIN    = LEGS(indl,end-6:end-4);
tIN     = LEGS(indl,end-2);

% --> flyby parameters
[muPLIN, radPLIN] = planetConstants(plIN);
[hmin, hmax]      = maxmin_flybyAltitude(plIN);
rpIN              = linspace(hmin, hmax, 50) + radPLIN; % [hmin:100:hmax] + radPLIN;
kIN               = deg2rad([0:10:360]);

% --> search for the optimal flyby
KEPOU    = zeros(length(rpIN)*length(kIN), 6);
KIN      = zeros(length(rpIN)*length(kIN), 1);
RPIN     = zeros(length(rpIN)*length(kIN), 1);
indmat = 1;
for indrp = 1:length(rpIN)
    rpin = rpIN(indrp);   % --> (km) periapsis of the hyperbola
    for indkp = 1:length(kIN)
        kin = kIN(indkp); % --> (rad) inclination of the hypberbola
        
        % --> perform the flyby of the last planet
        [rrOU, vvOU] = swingby_vA(rrIN, vvIN, plIN, tIN, kin, rpin, muPLIN);
        
        % --> compute the orbit after the flyby
        kepOU = car2kep([rrOU, vvOU], mu); 
        
        KEPOU(indmat, :) = kepOU;
        KIN(indmat,:)    = kin;
        RPIN(indmat,:)   = rpin;
        
        indmat = indmat + 1;
    end
end

incOUdeg           = rad2deg(KEPOU(:,3));
[incoudegmax, row] = max(incOUdeg);

vinfD = LEGS(indl,9);
vinfD = (vinfD - vdep)*(vinfD - vdep>=0);

totCost            = sum([ vinfD sum(LEGS(indl, 10:10:end ), 2) ], 2);
tdep               = LEGS(indl,8);
tin                = LEGS(indl,end-2);
epochs             = LEGS(indl, 8:10:end-2);
revs               = REVS(indl,:);

% --> save the results
STRUC.indl      = indl;
STRUC.tDEP      = tdep;
STRUC.tIN       = tin;
STRUC.epochs    = epochs;
STRUC.KEPOU     = KEPOU;
STRUC.incOU_deg = incOUdeg;

STRUC.rpin      = rpIN;
STRUC.kin       = kIN;

STRUC.incOUdegM = incoudegmax;
STRUC.kinM      = KIN(row);
STRUC.rpinM     = RPIN(row);
STRUC.kepOUM    = KEPOU(row,:);

STRUC.revs      = revs;
STRUC.totCost   = totCost;

end
