function [MSSTRUC] = process2_RESTOUR(LEGS, RES, MAXRESLEG, minMax, parallel)

plT      = LEGS(1,end-3); % --> target planet
tolINCL  = deg2rad(1);

INDRES    = [1:size(RES,1)]';
M         = permn_v2(INDRES, MAXRESLEG);

LEGS_next = LEGS;

% --> step 1
col = unique(M(:,1));
for indc = 1:size(col,1)
    resindeces  = col(indc,1);
    tic
    STRUC(indc) = wrap_COMB_RES(indc, LEGS_next, resindeces, RES, plT,...
        tolINCL, minMax, parallel);
    toc
end
% --> eliminate those that do not reach any resonance
emptyIndex        = find(arrayfun(@(STRUC) isempty(STRUC.maxIncD),STRUC));
indemptyRES       = col([STRUC(emptyIndex).indm]');
STRUC(emptyIndex) = [];
indxs = [];
for indempty = 1:length(indemptyRES)
    indxs = [indxs find( M(:,1) == indemptyRES(indempty))];
end
M(indxs,:) = [];

MSSTRUC = struct('m', []);
for indm = 1:size(M,2)
    MSSTRUC(indm).m = unique(M(:,1:indm), 'rows', 'stable');
end
MSSTRUC(1).STRUC = STRUC;

% --> add the successive resonant transfers - STEP 2
for indms = 2:MAXRESLEG

    m = MSSTRUC(indms).m;
    clear STRUC
    for indmm = 1:size(m,1)
        
        fprintf('running indm : %d of %d \n', [indmm, size(m,1)]);

        node   = m(indmm,:);
        prevn  = node(1:end-1); % --> previous resonant path
        nextn  = node(end);     % --> the next one

        if indms == 2
            indxs = find((abs(MSSTRUC(indms-1).m - prevn)')' == 0);
        else
            indxs = find(vecnorm(abs(MSSTRUC(indms-1).m - prevn)')' == 0);
        end

        maxIncDPrev = MSSTRUC(indms-1).STRUC(indxs).maxIncD;

        tic
        if isempty(maxIncDPrev) % --> stop the resonance tour there
            STRUC(indmm).indm        = prevn(end-1);
            STRUC(indmm).LEGS        = [];
            STRUC(indmm).TOFyMaxIncD = [];
        else
            LEGS_next = MSSTRUC(indms-1).STRUC(indxs).LEGS;
            if indms == 2
                pn = prevn(end);
            else
                pn = prevn(end-1);
            end
            STRUC(indmm) = wrap_COMB_RES(pn, LEGS_next, nextn, RES, plT, tolINCL, minMax, parallel);
        end
        toc

    end
    MSSTRUC(indms).STRUC = STRUC;

end

% --> post-process
MSSTRUCsave = MSSTRUC;

% --> post-process
for indms = 1:length(MSSTRUC)
    STRUC = MSSTRUC(indms).STRUC;
    for inds = 1:length(STRUC)
        if isempty(STRUC(inds).maxIncD)
            STRUC(inds).maxIncD     = NaN;
            STRUC(inds).LEGS        = [];
            STRUC(inds).legMaxIncD  = [];
            STRUC(inds).TOFyMaxIncD = [];
        end
    end
    MSSTRUC(indms).STRUC = STRUC;
end

for indms = 1:length(MSSTRUC)
    
    STRUC = MSSTRUC(indms).STRUC;
    for inds = 1:length(STRUC)
        LEGS = STRUC(inds).LEGS;
        if ~isempty(LEGS)
            kep              = legs2kep(LEGS);
            STRUC(inds).kep  = kep;
            STRUC(inds).incD = rad2deg(kep(:,3));
            STRUC(inds).TOFy = (LEGS(:,end-2) - LEGS(:,8))./365.25;
        end
        
    end
    MSSTRUC(indms).STRUC = STRUC;
    
end

end
