
clearDeleteAdd;

seq  = [3 2 3]; res = [ ];

%%%%%%%%%% multi-rev. options %%%%%%%%%%
maxrev  = 2;                       % --> max. number of revolutions
[RevMax, RevRed_OnlyZero, RevRed_FirstLast, RevRed_LastLeg] = ...
    differentRuns_v2(seq, maxrev); % --> generate successive runs
chosenRevs = RevMax; % --> process the resonances options
% chosenRevs = maxLegOneRev(chosenRevs);
[INPUT.chosenRevs, INPUT.res] = processResonances(chosenRevs, res); 
[INPUT.chosenRevs] = maxRevOuterPlanets(seq, INPUT.chosenRevs); chosenRevs = INPUT.chosenRevs;
%%%%%%%%%% multi-rev. options %%%%%%%%%%

%%%% set departing options %%%%
t0 = date2mjd2000([2031 2 1 0 0 0]);
tf = t0 + 1*365.25;         % --> final date range (MJD2000)
dt = 2;                     % --> step size (days)
INPUT.depOpts = [t0 tf dt];
%%%% set departing options %%%%

%%%% set options %%%%
INPUT.vInfOpts = [3 5];      % --> max/min departing infinity velocities (km/s)
INPUT.dsmOpts  = [0.2 Inf];  % --> max defect DSM, and total DV (km/s)
INPUT.bw       = Inf;        % --> beam width (single leg)
INPUT.SOMO     = 2;          % --> SOMO = 1 is for SO, SOMO = 2 is for MO
INPUT.plot     = [1 1];      % --> plot(1) for pareto front, plot(2) for best traj.
INPUT.write    = false;      % --> write best traj. to a file
INPUT.parallel = true;       % --> use parallel

% --> limit on infinty velocity at the planet
INPUT.vInfLim = [ [0 1e99]; [0 1e99]; [0 1e99]; [0 1e99]; [15 1e99]];   % --> PL1, PL2, PL3, ...   

vdep    = 0;
varr    = 0;
sigma   = 0;
impvarr = 0;

INPUT.costFunc1 = @(legn, vvf, vinff) costFunction1_DP_vdep(legn, vvf, vinff, vdep, sigma);
INPUT.costFunc2 = @(legn, vvf, vinff) costFunction2_DP_onlyDef(legn, vvf, vinff, vdep, varr, sigma, impvarr);

%%%% set options %%%%

%% --> OPTIMIZATION with DYNAMIC PROGRAMMING

% --> Dynamic Programming for MGA
OUTPUT = ASTRA_SODP_v2(INPUT, seq);

%% --> RESTOUR

minMax    = 2;               % --> maximise the inclination
RES       = [ [1 1]; [2 3]]; % --> Earth resonances
MAXRESLEG = 8;               % --> max. number of resonant legs
parallel  = 1;

% --> wrap RESTOUR
MSSTRUC = wrap_RESTOUR(OUTPUT, RES, MAXRESLEG, minMax, parallel);

% --> extract max. inclination path
[path, yy, tt, maxincoud] = extractPATH_flyby_maxIncl(MSSTRUC, 4, 2);

%% --> PLOT PATH

plotPath(path);
hold on;
plot3(yy(:,1)./astroConstants(2), yy(:,2)./astroConstants(2), yy(:,3)./astroConstants(2), 'r', 'linewidth', 2,...
    'DisplayName', 'Orbit after last fly-by');
legend( 'Location', 'Best' );
